==> scanbot_sdk-2.13.0-alpha01.tar.gz: lib/json/common.dart <==
import 'dart:math';

import 'package:json_annotation/json_annotation.dart';
import '../sdk_utils.dart';

import 'common_platform.dart';

part 'common.g.dart';

///Document detection status
enum DetectionStatus {
  OK,
  OK_BUT_TOO_SMALL,
  OK_BUT_BAD_ANGLES,
  OK_BUT_BAD_ASPECT_RATIO,
  OK_OFF_CENTER,
  OK_BARCODE,
  ERROR_NOTHING_DETECTED,
  ERROR_TOO_DARK,
  ERROR_TOO_NOISY
}

enum ImageFormat { JPG, PNG }

///Standart result status
enum OperationResult { SUCCESS, ERROR, CANCELED }

///Parent result class for ready to use components return data
class Result {
  ///Standart result status
  @JsonKey(includeToJson: false, includeFromJson: false)
  OperationResult? operationResult = OperationResult.SUCCESS;

  ///Message with description of returned result, for example, error message
  String? message;

  Result();
}

@JsonSerializable(includeIfNull: false)
class Rect {
  double? width;
  double? height;

  double? x;
  double? y;

  Rect(this.x, this.y, this.width, this.height);

  factory Rect.fromJson(Map<String, dynamic> json) => _$RectFromJson(json);

  Map<String, dynamic> toJson() => _$RectToJson(this);
}

@JsonSerializable(includeIfNull: false)
class PolygonPoint extends Point {
  PolygonPoint(num x, num y) : super(x, y);

  factory PolygonPoint.fromJson(Map<String, dynamic> json) =>
      _$PolygonPointFromJson(json);

  Map<String, dynamic> toJson() => _$PolygonPointToJson(this);
}

/// The Scanbot SDK provides a ready-to-use UI for document scanning and cropping.
///Both components use the notion of a 'page' as a data model for the scanning and cropping activities.
@JsonSerializable(includeIfNull: false, explicitToJson: true)
class Page {
  /// The detection result of the document detection operation that produced the page (either the document scanner or detectDocument()).
  DetectionStatus? detectionStatus;

  ///Limits the maximum resolution (width, height) of the document image. If null is passed, this property is effectively ignored. If specified, width and height must be > 0.
  Size? documentImageSizeLimit;

  /// The image filter which was applied to the document image of this page.
  ImageFilterType? filter;

  ///A string identifying the page in the internal page file storage
  String pageId;

  /// The page's cropping polygon as calculated by a document detection operation or as set by the cropping UI. Modifying the polygon will change the polygon as shown in the cropping UI but will not automatically re-crop the original image.
  List<PolygonPoint>? polygon;

  ///File URI of the original image
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri? originalImageFileUri;

  ///File URI of the cropped document image (if document detection was successful)
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri? documentImageFileUri;

  ///File URI of a screen-sized preview of the original image
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri? originalPreviewImageFileUri;

  ///File URI of a screen-sized preview of the document image
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri? documentPreviewImageFileUri;

  Page(this.pageId,
      {this.detectionStatus,
      this.documentImageSizeLimit,
      this.filter,
      this.polygon,
      this.originalImageFileUri,
      this.documentImageFileUri,
      this.originalPreviewImageFileUri,
      this.documentPreviewImageFileUri});

  factory Page.fromJson(Map<String, dynamic> json) => _$PageFromJson(json);

  Map<String, dynamic> toJson() => _$PageToJson(this);
}

@JsonSerializable(includeIfNull: false)
class Insets {
  /// Pixel for the finder window from the left.
  final double? left;

  /// Pixel for the finder window from the top.
  final double? top;

  /// Pixel for the finder window from the bottom.
  final double? bottom;

  /// Pixel for the finder window from the right.
  final double? right;

  const Insets({this.left, this.top, this.bottom, this.right});

  factory Insets.fromJson(Map<String, dynamic> json) => _$InsetsFromJson(json);

  factory Insets.all(double all) =>
      Insets(left: all, top: all, right: all, bottom: all);

  factory Insets.vertical(double inset) =>
      Insets(left: 0, top: inset, right: 0, bottom: inset);

  factory Insets.horizontal(double inset) =>
      Insets(left: inset, top: 0, right: inset, bottom: 0);

  Map<String, dynamic> toJson() => _$InsetsToJson(this);
}

/// A class that contains additional parameters for barcodes detection and filtering.
@JsonSerializable(
    includeIfNull: false, explicitToJson: true, createFactory: false)
class BarcodeAdditionalParameters {
  /// With this option, the scanner assumes that the barcode can be a GS1 barcode, and modifies the behavior as needed.
  /// You can set it to FALSE, if you don't want to see decoded FNC1 characters ("]C1" and ASCII char 29).
  /// The default is TRUE.
  bool? enableGS1Decoding;

  /// Minimum required text length of the detected barcode.
  /// The default is 0.
  /// NOTE: Currently works for ITF barcodes only!
  int? minimumTextLength;

  /// Maximum text length of the detected barcode. Setting to zero removes the limit.
  /// The default is 0.
  /// NOTE: Currently works for ITF barcodes only!
  int? maximumTextLength;

  /// Minimum required quiet zone on the barcode. Measured in modules (the size of minimal bar on the barcode).
  /// The default is 10.
  /// NOTE: Currently works for ITF barcodes only!
  int? minimum1DBarcodesQuietZone;

  /// The checksum algorithm for MSI Plessey barcodes.
  /// The default value is `Mod10'
  MSIPlesseyChecksumAlgorithm? msiPlesseyChecksumAlgorithm;

  ///With this option enabled, the scanner removes checks digits for UPC, EAN and MSI Plessey codes. Has no effect if both single and double digit MSI Plessey checksums are enabled. The default is `false`
  bool? stripCheckDigits;

  BarcodeAdditionalParameters(
      {this.enableGS1Decoding,
      this.minimumTextLength,
      this.maximumTextLength,
      this.minimum1DBarcodesQuietZone,
      this.msiPlesseyChecksumAlgorithm,
      this.stripCheckDigits});

  Map<String, dynamic> toJson() => _$BarcodeAdditionalParametersToJson(this);
}

==> scanbot_sdk-4.2.1-alpha01.tar.gz: lib/json/common.dart <==
import 'dart:math';

import 'package:json_annotation/json_annotation.dart';
import '../sdk_utils.dart';

import 'common_platform.dart';

part 'common.g.dart';

/// Document detection status
enum DetectionStatus {
  OK,
  OK_BUT_TOO_SMALL,
  OK_BUT_BAD_ANGLES,
  OK_BUT_BAD_ASPECT_RATIO,
  OK_OFF_CENTER,
  OK_BARCODE,
  ERROR_NOTHING_DETECTED,
  ERROR_TOO_DARK,
  ERROR_TOO_NOISY
}

enum ImageFormat { JPG, PNG }

/// Standard result status
enum OperationResult { SUCCESS, ERROR, CANCELED }

/// Parent result class for ready-to-use UI components return data
class Result {
  /// Standard result status
  @JsonKey(includeToJson: false, includeFromJson: false)
  OperationResult? operationResult = OperationResult.SUCCESS;

  /// Message with description of returned result, for example, error message
  String? message;

  Result();
}

@JsonSerializable(includeIfNull: false)
class Rect {
  double? width;
  double? height;

  double? x;
  double? y;

  Rect(this.x, this.y, this.width, this.height);

  factory Rect.fromJson(Map<String, dynamic> json) => _$RectFromJson(json);

  Map<String, dynamic> toJson() => _$RectToJson(this);
}

@JsonSerializable(includeIfNull: false)
class PolygonPoint extends Point {
  PolygonPoint(num x, num y) : super(x, y);

  factory PolygonPoint.fromJson(Map<String, dynamic> json) =>
      _$PolygonPointFromJson(json);

  Map<String, dynamic> toJson() => _$PolygonPointToJson(this);
}

/// The Scanbot SDK provides a ready-to-use UI for document scanning and cropping.
/// Both components use the notion of a 'page' as a data model for the scanning and cropping activities.
@JsonSerializable(includeIfNull: false, explicitToJson: true)
class Page {
  /// The detection result of the document detection operation that produced the page (either the document scanner or detectDocument()).
  DetectionStatus? detectionStatus;

  /// Limits the maximum resolution (width, height) of the document image. If null is passed, this property is effectively ignored. If specified, width and height must be > 0.
  Size? documentImageSizeLimit;

  /// The image filter which was applied to the document image of this page.
  ImageFilterType? filter;

  /// A string identifying the page in the internal page file storage
  String pageId;

  /// The page's cropping polygon as calculated by a document detection operation or as set by the cropping UI. Modifying the polygon will change the polygon as shown in the cropping UI but will not automatically re-crop the original image.
  List<PolygonPoint>? polygon;

  /// File URI of the original image
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri? originalImageFileUri;

  /// File URI of the cropped document image (if document detection was successful)
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri? documentImageFileUri;

  /// File URI of a screen-sized preview of the original image
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri? originalPreviewImageFileUri;

  /// File URI of a screen-sized preview of the document image
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri? documentPreviewImageFileUri;

  Page(this.pageId,
      {this.detectionStatus,
      this.documentImageSizeLimit,
      this.filter,
      this.polygon,
      this.originalImageFileUri,
      this.documentImageFileUri,
      this.originalPreviewImageFileUri,
      this.documentPreviewImageFileUri});

  factory Page.fromJson(Map<String, dynamic> json) => _$PageFromJson(json);

  Map<String, dynamic> toJson() => _$PageToJson(this);
}

@JsonSerializable(includeIfNull: false)
class Insets {
  /// Pixel for the finder window from the left.
  final double? left;

  /// Pixel for the finder window from the top.
  final double? top;

  /// Pixel for the finder window from the bottom.
  final double? bottom;

  /// Pixel for the finder window from the right.
  final double? right;

  const Insets({this.left, this.top, this.bottom, this.right});

  factory Insets.fromJson(Map<String, dynamic> json) => _$InsetsFromJson(json);

  factory Insets.all(double all) =>
      Insets(left: all, top: all, right: all, bottom: all);

  factory Insets.vertical(double inset) =>
      Insets(left: 0, top: inset, right: 0, bottom: inset);

  factory Insets.horizontal(double inset) =>
      Insets(left: inset, top: 0, right: inset, bottom: 0);

  Map<String, dynamic> toJson() => _$InsetsToJson(this);
}

/// A class that contains additional parameters for barcodes detection and filtering.
@JsonSerializable(
    includeIfNull: false, explicitToJson: true, createFactory: false)
class BarcodeAdditionalParameters {
  /// GS1 handling mode
  Gs1HandlingMode? gs1HandlingMode;

  /// Minimum required text length of the detected barcode.
  /// The default is 0.
  /// NOTE: Currently works for ITF barcodes only!
  int? minimumTextLength;

  /// Maximum text length of the detected barcode. Setting to zero removes the limit.
  /// The default is 0.
  /// NOTE: Currently works for ITF barcodes only!
  int? maximumTextLength;

  /// Minimum required quiet zone on the barcode. Measured in modules (the size of minimal bar on the barcode).
  /// The default is 10.
  /// NOTE: Currently works for ITF barcodes only!
  int? minimum1DBarcodesQuietZone;

  /// The checksum algorithm for MSI Plessey barcodes.
  /// The default value is `Mod10'
  MSIPlesseyChecksumAlgorithm? msiPlesseyChecksumAlgorithm;

  /// With this option enabled, the scanner removes checks digits for UPC, EAN and MSI Plessey codes. Has no effect if both single and double digit MSI Plessey checksums are enabled. The default is `false`
  bool? stripCheckDigits;

  BarcodeAdditionalParameters(
      {this.gs1HandlingMode,
      this.minimumTextLength,
      this.maximumTextLength,
      this.minimum1DBarcodesQuietZone,
      this.msiPlesseyChecksumAlgorithm,
      this.stripCheckDigits});

  Map<String, dynamic> toJson() => _$BarcodeAdditionalParametersToJson(this);
}

/// A class that contains result for document quality analyze
@JsonSerializable(
    includeIfNull: false, createToJson: false, createFactory: true)
class DocumentQualityResult {
  DocumentQuality? documentQuality;

  DocumentQualityResult({this.documentQuality});

  factory DocumentQualityResult.fromJson(Map<String, dynamic> json) =>
      _$DocumentQualityResultFromJson(json);
}

/// The PDF file attributes.
@JsonSerializable(
    includeIfNull: false,
    createFactory: false,
    createToJson: true,
    explicitToJson: true)
class PdfAttributes {
  /// The creator of the PDF document.
  final String creator;

  /// The author of the PDF document.
  final String author;

  /// The title of the PDF document.
  final String title;

  /// The subject of the PDF document.
  final String subject;

  /// The keywords of the PDF document.
  final String keywords;

  const PdfAttributes({
    required this.creator,
    required this.author,
    required this.title,
    required this.subject,
    required this.keywords,
  });

  Map<String, dynamic> toJson() => _$PdfAttributesToJson(this);
}
